#[non_exhaustive]pub enum ContentVersion {
Blob(BlobId),
Stamp(FileStamp),
}Expand description
Content identity carried by a node state.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Blob(BlobId)
Exact immutable content has been captured in the blob store.
Stamp(FileStamp)
Content is lazy; this metadata stamp must still match when it is captured.