pub enum DiffKind {
Create,
Delete,
Modify,
MetadataChange,
}Expand description
Semantic category of one canonical diff entry.
Variants
Create
A path absent from the base exists in final virtual state.
Delete
A base path is absent from final virtual state.
Modify
Node kind or content changed.
MetadataChange
Only retained metadata changed.