pub struct DiffEntry {
pub path: VPath,
pub before: Option<NodeState>,
pub after: Option<NodeState>,
pub kind: DiffKind,
}Expand description
One path change in a canonical virtual filesystem diff.
Fields
path: VPathChanged virtual path.
before: Option<NodeState>Base state, or None when this is a creation.
after: Option<NodeState>Final virtual state, or None when this is a deletion.
kind: DiffKindSemantic change category derived from before and after.