pub struct IntentDigest(/* private fields */);Expand description
The digest identity of transaction intent supplied out of band.
Implementations
Sourceimpl IntentDigest
impl IntentDigest
Sourceimpl IntentDigest
impl IntentDigest
Sourcepub fn digest_text(intent: &str) -> Self
pub fn digest_text(intent: &str) -> Self
Hash transaction intent without retaining its potentially sensitive text.