pub struct PrincipalId(/* private fields */);Expand description
The opaque digest identity of an independent approval principal.
Implementations
Sourceimpl PrincipalId
impl PrincipalId
Sourceimpl PrincipalId
impl PrincipalId
Sourcepub fn digest_label(label: &str) -> Self
pub fn digest_label(label: &str) -> Self
Hash a stable principal label without persisting it in transaction state.