TransactionBinding

Struct TransactionBinding 

pub struct TransactionBinding {
    pub base_snapshot: SnapshotId,
    pub diff: DiffDigest,
    pub read_set: ReadSetDigest,
    pub write_set: WriteSetDigest,
    pub program: ProgramDigest,
    pub policy: PolicyDigest,
    pub runtime_config: RuntimeConfigDigest,
    pub intent: Option<IntentDigest>,
}
Exact immutable inputs bound into an approval and commit identity.

Fields

base_snapshot: SnapshotId

Immutable base snapshot observed by virtual execution.

diff: DiffDigest

Exact canonical final diff.

read_set: ReadSetDigest

Exact dependencies read while deriving the result.

write_set: WriteSetDigest

Exact preconditions for paths the transaction will write.

program: ProgramDigest

Exact untrusted program source.

policy: PolicyDigest

Exact deterministic policy configuration.

runtime_config: RuntimeConfigDigest

Security-relevant execution configuration and budgets.

intent: Option<IntentDigest>

Optional out-of-band user intent shown to an approval principal.

Implementations

Source

impl TransactionBinding

pub fn transaction_id(self) -> TransactionId

Derive the single transaction identity to which approval and commit bind.